@@ -6,7 +6,7 @@ use POE 0.38 qw(Wheel::Run Filter::Line Filter::Reference);
 use vars qw($VERSION);
 use Carp;
 
-$VERSION = '1.08';
+$VERSION = '1.09';
 
 sub spawn {
   my $package = shift;
@@ -105,7 +105,19 @@ sub _shorten {
 	return;
   }
 
-  $args->{sender} = $sender;
+  if ( $args->{session} ) {
+    if ( my $ref = $kernel->alias_resolve( $args->{session} ) ) {
+	$args->{sender} = $ref->ID();
+    }
+    else {
+	warn "Could not resolve 'session' to a valid POE session\n";
+	return;
+    }
+  }
+  else {
+    $args->{sender} = $sender;
+  }
+
   $kernel->refcount_increment( $sender => __PACKAGE__ );
   $self->{wheel}->put( $args );
   undef;
@@ -273,6 +285,7 @@ Requires a hashref as first argument. The hashref should contain the following k
 
   'url', the url that you want shortening. ( Mandatory ).
   'event', the name of the event to send the reply to. ( Mandatory ).
+  'session', optional, an alternative session: alias, ref or ID that the response should be sent to, defaults to sending session;
 
 You may also pass arbitary key/values in the hashref ( as demonstrated in the SYNOPSIS ). Arbitary keys should have an underscore prefix '_'.
 
